<?php
/* $Id: latvian-windows-1257.inc.php,v 2.80 2005/07/29 17:03:18 lem9 Exp $ */

/**
 * Latvian language file by Sandis Jrics <sandisj at parks.lv>
 */

$charset = 'windows-1257';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Sv', 'P', 'O', 'T', 'C', 'Pk', 'S');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jn', 'Jl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y %H:%M';

$timespanfmt = '%s dienas, %s stundas, %s mintes un %s sekundes';

$strAPrimaryKey = 'Primr atslga pievienota uz lauka %s';
$strAbortedClients = 'Prtraukts';
$strAbsolutePathToDocSqlDir = 'Ldzu ievadiet absolto ceu ldz docSQL direktorijai uz servera';
$strAccessDenied = 'Pieeja aizliegta';
$strAccessDeniedExplanation = 'phpMyAdmin minja pieslgties MySQL serverim, un serveris noraidja pieslgumu. Ldzu prbaudiet hostu, lietotjvrdu un paroli config.inc.php fail, un prliecinieties, ka tie atbilst informcijai, ko Jums deva MySQL servera administrators.';
$strAction = 'Darbba';
$strAddAutoIncrement = 'Pievienot AUTO_INCREMENT vrtbu';
$strAddConstraints = 'Pievienot ierobeojumus';
$strAddDeleteColumn = 'Pievienot/Dzst laukus (kolonnas)';
$strAddDeleteRow = 'Pievienot/Dzst ierakstu';
$strAddDropDatabase = 'Pievienot DROP DATABASE';
$strAddFields = 'Pievienot %s lauku(s)';
$strAddHeaderComment = 'Ievietot virsrakst komentru (\\n atdala rindas)';
$strAddIfNotExists = 'Pievienot IF NOT EXISTS';
$strAddIntoComments = 'Pievienot komentros';
$strAddNewField = 'Pievienot jaunu lauku';
$strAddPrivilegesOnDb = 'Pievienot privilijas uz sekojoo  datubzi';
$strAddPrivilegesOnTbl = 'Pievienot privilijas uz sekojoo tabulu';
$strAddSearchConditions = 'Pievienot meklanas nosacjumus ("where" izteiksmes ermenis):';
$strAddToIndex = 'Pievienot indeksam &nbsp;%s&nbsp;kolonn(u/as)';
$strAddUser = 'Pievienot jaunu lietotju';
$strAddUserMessage = 'Js pievienojt jaunu lietotju.';
$strAddedColumnComment = 'Pievienots komentrs kolonnai';
$strAddedColumnRelation = 'Pievienota relcija kolonnai';
$strAdministration = 'Administrcija';
$strAffectedRows = 'Ietekmto rindu skaits:';
$strAfter = 'Pc %s';
$strAfterInsertBack = 'Atgriezties atpaka iepriekj lap';
$strAfterInsertNewInsert = 'Ievietot vl vienu rindu';
$strAfterInsertSame = 'Atgriezties aj lap';
$strAll = 'Visi';
$strAllTableSameWidth = 'rdt visas tabulas vienad platum?';
$strAlterOrderBy = 'Maint datu krtoanas laukus';
$strAnIndex = 'Indekss tieka pievienots uz %s';
$strAnalyzeTable = 'Analizt tabulu';
$strAnd = 'Un';
$strAny = 'Jebkur';
$strAnyHost = 'Jebkur hosts';
$strAnyUser = 'Jebkur lietotjs';
$strApproximateCount = 'Var bt aptuvens skaits. Skatt FAQ 3.11';
$strArabic = 'Arbu';
$strArmenian = 'Armu';
$strAscending = 'Augo secb';
$strAtBeginningOfTable = 'Tabulas skum';
$strAtEndOfTable = 'Tabulas beigs';
$strAttr = 'Atribti';
$strAutodetect = 'Noteikt automtiski';
$strAutomaticLayout = 'Automtiskais izvietojums';

$strBack = 'Atpaka';
$strBaltic = 'Baltijas';
$strBeginCut = 'IZGRIEZT NO S VIETAS';
$strBeginRaw = 'RINDAS SKUMS';
$strBinLogEventType = 'Notikuma tips';
$strBinLogInfo = 'Informcija';
$strBinLogName = 'Log-faila nosaukums';
$strBinLogOriginalPosition = 'Oriinl pozcija';
$strBinLogPosition = 'Pozcija';
$strBinLogServerId = 'Servera ID';
$strBinary = 'Binrais';
$strBinaryDoNotEdit = 'Binrais - netiek labots';
$strBinaryLog = 'Binrais log-fails';
$strBookmarkAllUsers = 'Dot ikvienam lietotjam pieeju ai grmatzmei';
$strBookmarkDeleted = 'Ieraksts tika dzsts.';
$strBookmarkLabel = 'Nosaukums';
$strBookmarkOptions = 'Grmatzmju opcijas';
$strBookmarkQuery = 'Saglabtie SQL vaicjumi';
$strBookmarkThis = 'Saglabt o SQL vaicjumu';
$strBookmarkView = 'Tikai apskatt';
$strBrowse = 'Apskatt';
$strBrowseForeignValues = 'Prlkot rjs vrtbas';
$strBulgarian = 'Bulgru';
$strBzError = 'phpMyAdmin nevarja saarhivt failu d bojta Bz2 paplainjuma aj php versij. Stingri rekomendjam uzstdt <code>$cfg[\'BZipDump\']</code> direktvu phpMyAdmin konfigurcijas fail uz <code>FALSE</code>. Ja vlaties lietot Bz2 kompresijas iespjas, Jums juzliek jaunka php versija. Skatt php bug report %s skkai informcijai.';
$strBzip = 'Arhivts ar bzip';

$strCSVOptions = 'CSV opcijas';
$strCalendar = 'Kalendrs';
$strCannotLogin = 'Nevar pieslgties MySQL serverim';
$strCantLoad = 'nevar ieldt paplainjumu %s,<br />ldzu prbaudiet PHP konfigurciju';
$strCantLoadRecodeIconv = 'Nevar ieldt iconv vai recode paplainjumu, kas ir nepiecieams rakstzmju konvertcijai, ldzu nokonfigurjiet php, lai vartu lietot os paplainjumus, vai ar atsldziet rakstzmju konvertciju phpMyAdmin konfigurcij.';
$strCantRenameIdxToPrimary = 'Nevar prsaukt indeksu par PRIMARY!';
$strCantUseRecodeIconv = 'Nevar lietot iconv, libiconv vai recode_string funkciju, bet php saka, ka paplainjums ir ieldts. Prbaudiet php konfigurciju.';
$strCardinality = 'Kardinalitte';
$strCarriage = 'Rindas nobeiguma simbols: \\r';
$strCaseInsensitive = 'reistrnejtgs';
$strCaseSensitive = 'reistrjtgs';
$strCentralEuropean = 'Centrleiropas';
$strChange = 'Labot';
$strChangeCopyMode = 'Izveidot jaunu lietotju ar tdm pam privilijm un ...';
$strChangeCopyModeCopy = '... paturt veco lietotju.';
$strChangeCopyModeDeleteAndReload = ' ... dzst veco lietotju no lietotju tabulas, un pc tam prldt privilijas.';
$strChangeCopyModeJustDelete = ' ... dzst veco lietotju no lietotju tabulas.';
$strChangeCopyModeRevoke = ' ... atemt vecajam lietotjam visas aktvs privilijas, un pc tam dzst viu.';
$strChangeCopyUser = 'Maint piekuves informciju / Klont lietotju';
$strChangeDisplay = 'Izvlieties, kuru lauku rdt';
$strChangePassword = 'Maint paroli';
$strCharset = 'Kodjums';
$strCharsetOfFile = 'Tabulas kodjums:';
$strCharsets = 'Rakstzmju kodjumi';
$strCharsetsAndCollations = 'Rakstzmju kodjumi un izkrtojumi';
$strCheckAll = 'Iezmt visu';
$strCheckOverhead = 'Iezmt tabulas ar prtriu';
$strCheckPrivs = 'Prbaudt privilijas';
$strCheckPrivsLong = 'Prbaudt privilijas uz datubzi &quot;%s&quot;.';
$strCheckTable = 'Prbaudt tabulu';
$strChoosePage = 'Izvlieties lapu rediganai';
$strColComFeat = 'Rdu kolonnu komentrus';
$strCollation = 'Izkrtojumi';
$strColumnNames = 'Kolonnu nosaukumi';
$strColumnPrivileges = 'Kolonnu specifisks privilijas';
$strCommand = 'Komanda';
$strComments = 'Komentri';
$strCommentsForTable = 'KOMENTRI TABULAI';
$strCompatibleHashing = 'MySQL&nbsp;4.0 savietojams';
$strCompleteInserts = 'Pilnas INSERT izteiksmes';
$strCompression = 'Kompresija';
$strConfigFileError = 'phpMyAdmin nevar nolast konfigurcijas failu!<br />Tas var notikt, ja PHP atrod taj kdu, vai ar nevar atrast so failu.<br />Mginiet izsaukt konfigurcijas failu tiei, klikkinot linku zemk un lasiet PHP pazinojumu par kdm. Vairkum gadjumu kaut kur pietrukst pdia vai semikols.<br />Ja redzat tuku lapu, viss ir krtb.';
$strConfigureTableCoord = 'Ldzu konfigurjiet koordintes tabulai %s';
$strConnectionError = 'Nevar pieslgties: kda konfigurcij.';
$strConnections = 'Konekcijas';
$strConstraintsForDumped = 'Ierobeojumi izmestm tabulm';
$strConstraintsForTable = 'Ierobeojumi tabulai';
$strCookiesRequired = '"Cookies" ir jbt atautiem aiz  punkta.';
$strCopyDatabaseOK = 'Datubze %s tika prkopta uz %s';
$strCopyTable = 'Kopt tabulu uz (datubze<b>.</b>tabula):';
$strCopyTableOK = 'Tabula %s tika prkopta uz %s.';
$strCopyTableSameNames = 'Nevar nokopt tabulu uz viu pau!';
$strCouldNotKill = 'phpMyAdmin nevarja nogalint procesu %s. Iespjams, ka tas jau agrk tika izbeigts.';
$strCreate = 'Izveidot';
$strCreateIndex = 'Izveidot indeksu uz&nbsp;%s&nbsp;laukiem';
$strCreateIndexTopic = 'Izveidot jaunu indeksu';
$strCreateNewDatabase = 'Izveidot jaunu datubzi';
$strCreateNewTable = 'Izveidot jaunu tabulu datubz %s';
$strCreatePage = 'Izveidot jaunu lapu';
$strCreatePdfFeat = 'PDF failu izveide';
$strCreationDates = 'Izveidoanas/Atjaunoanas/Piekuves datumi';
$strCriteria = 'Kritrijs';
$strCroatian = 'Horvtu';
$strCyrillic = 'Kirilisks';
$strCzech = 'ehu';
$strCzechSlovak = 'ehu-Slovku';

$strDBComment = 'Datubzes komentrs: ';
$strDBCopy = 'Kopt datubzi uz';
$strDBGContext = 'Konteksts';
$strDBGContextID = 'Konteksta ID';
$strDBGHits = 'Apmekljumi';
$strDBGLine = 'Lnija';
$strDBGMaxTimeMs = 'Maks. laiks, ms';
$strDBGMinTimeMs = 'Min. laiks, ms';
$strDBGModule = 'Modulis';
$strDBGTimePerHitMs = 'Viena apmekljuma laiks, ms';
$strDBGTotalTimeMs = 'Laiks kop, ms';
$strDBRename = 'Prsaukt datubzi par';
$strDanish = 'Du';
$strData = 'Dati';
$strDataDict = 'Datu vrdnca';
$strDataOnly = 'Tikai dati';
$strDatabase = 'Datubze';
$strDatabaseEmpty = 'Datubzes nosaukums ir tuks!';
$strDatabaseExportOptions = 'Datubzu eksporta opcijas';
$strDatabaseHasBeenDropped = 'Datubze %s tika izdzsta.';
$strDatabaseNoTable = 'aj datubz nav tabulu!';
$strDatabases = 'Datubzes';
$strDatabasesDropped = '%s datubzes tika veiksmgi dzstas.';
$strDatabasesStats = 'Datubzu statistika';
$strDatabasesStatsDisable = 'Izslgt statistiku';
$strDatabasesStatsEnable = 'Ieslgt statistiku';
$strDatabasesStatsHeavyTraffic = 'Piezme: Datubzes statistikas ieslgana eit var izsaukt palielinto datu apmaiu starp webserveri un MySQL serveri.';
$strDbPrivileges = 'Datubu specifisks privilijas';
$strDbSpecific = 'datubzei specifisks';
$strDefault = 'Noklusts';
$strDefaultValueHelp = 'Noklustajm vrtbm, ldzu ievadiet tikai pau vertbu, bez izsargans ar atpakajo slpsvtru vai pdim, lietojot o formatu: a';
$strDefragment = 'Defragmentt tabulu';
$strDelOld = 'Tekoaj lap ir atsauces uz tabulm, kas vairs neeksist. Vai Js gribat dzst s atsauces?';
$strDelayedInserts = 'Lietot aizturtos INSERT';
$strDelete = 'Dzst';
$strDeleteAndFlush = 'Dzst lietotjus, un pc tam prldt privilijas.';
$strDeleteAndFlushDescr = 'Tas ir labkais veids, bet priviliju prldana var paemt zinmu laiku.';
$strDeleted = 'Ieraksts tika dzsts';
$strDeletedRows = 'Ieraksti dzsti:';
$strDeleting = 'Dzam %s';
$strDescending = 'Dilsto secb';
$strDescription = 'Apraksts';
$strDictionary = 'vrdnca';
$strDisableForeignChecks = 'Neprbaudt rjs atslgas';
$strDisabled = 'Izslgts';
$strDisplayFeat = 'Rdt iespjas';
$strDisplayOrder = 'Attloanas secba:';
$strDisplayPDF = 'Rdt PDF shmu';
$strDoAQuery = 'Izpildt "vaicjumu pc parauga" (aizstjjzme: "%")';
$strDoYouReally = 'Vai Js tiem gribat ';
$strDocu = 'Dokumentcija';
$strDrop = 'Likvidt';
$strDropDatabaseStrongWarning = 'Js taisaties LIKVIDT veselu datubzi!';
$strDropSelectedDatabases = 'Dzst iezmts datubzes';
$strDropUsersDb = 'Dzst datubzes, kurm ir tdi pai vrdi, k lietotjiem.';
$strDumpSaved = 'Damps tika saglabts fail %s.';
$strDumpXRows = 'Saglabt %s rindas, skot ar %s.';
$strDumpingData = 'Dati tabulai';
$strDynamic = 'dinamisks';

$strEdit = 'Labot';
$strEditPDFPages = 'Labot PDF lapas';
$strEditPrivileges = 'Maint privilijas';
$strEffective = 'Efektvs';
$strEmpty = 'Iztukot';
$strEmptyResultSet = 'MySQL atgrieza tuko rezulttu (0 rindas).';
$strEnabled = 'Ieslgts';
$strEncloseInTransaction = 'Iekaut eksportu transakcij';
$strEnd = 'Beigas';
$strEndCut = 'IZGRIEZT LDZ AI VIETAI';
$strEndRaw = 'RINDAS BEIGAS';
$strEnglish = 'Angu';
$strEnglishPrivileges = ' Piezme: MySQL priviliju apzmjumi tiek rakstti angu valod ';
$strError = 'Kda';
$strEscapeWildcards = 'Aizstjjzmes _ un % jaizsarg ar \ priek, lai izmantotu ts burtiski';
$strEstonian = 'Igauu';
$strExcelEdition = 'Excel redakcija';
$strExcelOptions = 'Excel opcijas';
$strExecuteBookmarked = 'Izpildt iegrmatoto vaicjumu';
$strExplain = 'Izskaidrot SQL';
$strExport = 'Eksports';
$strExtendedInserts = 'Paplaintas INSERT izteiksmes';
$strExtra = 'Ekstras';

$strFailedAttempts = 'Neveiksmgi minjumi';
$strField = 'Lauks';
$strFieldHasBeenDropped = 'Lauks %s tika izdzsts';
$strFields = 'Lauki';
$strFieldsEmpty = ' Lauku skaits ir nulle! ';
$strFieldsEnclosedBy = 'Lauki iekauti iek';
$strFieldsEscapedBy = 'Glbjoa (escape) rakstzme ir';
$strFieldsTerminatedBy = 'Lauki atdalti ar';
$strFileAlreadyExists = 'Fails %s jau eksist uz servera. Ldzu nomainiet faila nosaukumu vai atzmjiet failu prrakstanas opciju.';
$strFileCouldNotBeRead = 'Nevar nolast failu';
$strFileNameTemplate = 'Faila nosaukuma ablons';
$strFileNameTemplateHelp = 'Lietojiet __DB__ datubzes nosaukumam, __TABLE__ tabulas nosaukumam un funkcijas %sstrftime%s opcijas laika nordsanai, faila paplainjums tiks automtiski pievienots. Jebkds cits teksts tiks atstts bez izmaim.';
$strFileNameTemplateRemember = 'atcerties ablonu';
$strFixed = 'fiksts';
$strFlushPrivilegesNote = 'Piezme: phpMyAdmin saem lietotju privilijas pa taisno no MySQL priviliju tabilm. o tabulu saturs var atirties no privilijm, ko lieto serveris, ja tur tika veikti labojumi. aj gadjum ir nepiecieams %sprldt privilijas%s pirms Js turpint.';
$strFlushTable = 'Atsvaidzint tabulu ("FLUSH")';
$strFormEmpty = 'Form trkst vrtbu!';
$strFormat = 'Formats';
$strFullText = 'Pilni teksti';
$strFunction = 'Funkcija';

$strGenBy = 'Uzenerja';
$strGenTime = 'Izveidoanas laiks';
$strGeneralRelationFeat = 'Galvens relciju pabas';
$strGeorgian = 'Gruznu';
$strGerman = 'Vcu';
$strGlobal = 'globls';
$strGlobalPrivileges = 'Globls privilijas';
$strGlobalValue = 'Globl vrtba';
$strGo = 'Aiziet!';
$strGrantOption = 'Pieirt';
$strGreek = 'Grieu';
$strGzip = 'Arhivts ar gzip';

$strHasBeenAltered = 'tika modificta.';
$strHasBeenCreated = 'tika izveidota.';
$strHaveToShow = 'Izvlieties vismaz vienu kolonnu attloanai';
$strHebrew = 'Ebreju';
$strHexForBinary = 'Lietot heksadecimlo formtu binrajiem laukiem';
$strHome = 'Skumlapa';
$strHomepageOfficial = 'Oficil phpMyAdmin mjaslapa';
$strHost = 'Hosts';
$strHostEmpty = 'Hosts nav nordts!';
$strHungarian = 'Ungru';

$strIcelandic = 'Islandieu';
$strId = 'ID';
$strIdxFulltext = 'Pilni teksti';
$strIfYouWish = 'Ja Js vlaties ieldt tikai daas tabulas kolonnas, nordiet to nosaukumus, atdalot tos ar komatu.';
$strIgnore = 'Ignort';
$strIgnoreInserts = 'Lietot IGNORE INSERTS';
$strIgnoringFile = 'Ignorjam failu %s';
$strImportDocSQL = 'Importt docSQL failus';
$strImportFiles = 'Importt failus';
$strImportFinished = 'Imports pabeigts';
$strInUse = 'lietoan';
$strIndex = 'Indekss';
$strIndexHasBeenDropped = 'Indekss %s tika izdzsts';
$strIndexName = 'Indeksa nosaukums&nbsp;:';
$strIndexType = 'Indeksa tips&nbsp;:';
$strIndexWarningMultiple = 'Vairk k viena %s atslga tika izveidota kolonnai `%s`';
$strIndexWarningPrimary = 'PRIMARY un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
$strIndexWarningTable = 'Problmas ar indeksiem tabul `%s`';
$strIndexWarningUnique = 'UNIQUE un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
$strIndexes = 'Indeksi';
$strInnodbStat = 'InnoDB statuss';
$strInsecureMySQL = 'Jsu konfigurcijas fails satur iestdjumus (lietotjs "root" bez paroles), kas atbilst noklustajam MySQL privilitajam lietotjam. Jsu MySQL serveris strd ar o noklusto variantu, ir atvrts uzbrukumiem, un Jums tiem jaiztaisa is drobas caurums.';
$strInsert = 'Pievienot';
$strInsertAsNewRow = 'Ievietot k jaunu rindu';
$strInsertBookmarkTitle = 'Ldzu ierakstiet grmatzmes virsrakstu';
$strInsertNewRow = 'Pievienot jaunu rindu';
$strInsertTextfiles = 'Ievietot tabul datus no teksta faila';
$strInsertedRowId = 'Ievietots rindas id:';
$strInsertedRows = 'Rindas pievienotas:';
$strInstructions = 'Instrukcijas';
$strInternalNotNecessary = '* Iekj relcija nav nepiecieama, kad t eksist ar iek InnoDB.';
$strInternalRelations = 'Iekjs relcijas';

$strJapanese = 'Japu';
$strJumpToDB = 'priet pie datubzes &quot;%s&quot;.';
$strJustDelete = 'Dzst lietotjus no priviliju tabulm.';
$strJustDeleteDescr = '&quot;Dzstie&quot; lietotji saglab spju piekt serverim k parasti, ldz privilijas tiek prldtas.';

$strKeepPass = 'Nemaint paroli';
$strKeyname = 'Atslgas nosaukums';
$strKill = 'Nogalint';
$strKorean = 'Korejieu';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX opcijas';
$strLandscape = 'Ainava';
$strLatexCaption = 'Tabulas virsraksts';
$strLatexContent = 'Tabulas __TABLE__ saturs';
$strLatexContinued = '(turpinjums)';
$strLatexContinuedCaption = 'Tabulas virsraksta turpinjums';
$strLatexIncludeCaption = 'Iekaut tabulas virsrakstu';
$strLatexLabel = 'Etietes atslga';
$strLatexStructure = 'Tabulas __TABLE__ struktra';
$strLatvian = 'Latvieu';
$strLengthSet = 'Garums/Vrtbas*';
$strLimitNumRows = 'Rindu skaits vien lap';
$strLineFeed = 'Rindas beigu simbols: \\n';
$strLinesTerminatedBy = 'Rindas atdaltas ar';
$strLinkNotFound = 'Links nav atrasts';
$strLinksTo = 'Linki uz';
$strLithuanian = 'Lietuvieu';
$strLoadExplanation = 'Labk metode ir izvlta pc noklusjuma, bet Js varat maint to neveiksmes gadjum.';
$strLoadMethod = 'LOAD metode';
$strLocalhost = 'Lokls';
$strLocationTextfile = 'Teksta faila atraans vieta';
$strLogPassword = 'Parole:';
$strLogServer = 'Serveris';
$strLogUsername = 'Lietotjvrds:';
$strLogin = 'Ieiet';
$strLoginInformation = 'Piekuves informcija';
$strLogout = 'Iziet';

$strMIMETypesForTable = 'MIME TIPI TABULAI';
$strMIME_MIMEtype = 'MIME tips';
$strMIME_available_mime = 'Pieejamie MIME tipi';
$strMIME_available_transform = 'Pieejams transformcijas';
$strMIME_description = 'Apraksts';
$strMIME_nodescription = 'ai transformcijai nav apraksta.<br />Jautjiet autoram, ko %s dara.';
$strMIME_transformation = 'Prlkprogrammas transformcija';
$strMIME_transformation_note = 'Lai iegtu pieejamo transformciju opcijas un to MIME tipu transformcijas, uzklikiniet uz %stransformciju apraksti%s';
$strMIME_transformation_options = 'Transformcijas opcijas';
$strMIME_transformation_options_note = 'Ldzu ievadiet transformciju opciju vrtbas, lietojot o formatu: \'a\',\'b\',\'c\'...<br />Ja Jums jlieto atpakaj slpsvtra ("\") vai vienkr pdia ("\'") starp m vrtbm, lieciet ts priek vl vienu atpakajo slpsvtru (piemram \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME tipiem, kas pardti slprakst, nav atsevias transformcijas funkcijas';
$strMaximumSize = 'Maksimlais izmrs: %s%s';
$strModifications = 'Labojumi tika saglabti';
$strModify = 'Labot';
$strModifyIndexTopic = 'Labot indeksu';
$strMoreStatusVars = 'Vairk statusa maingie';
$strMoveTable = 'Prvietot tabulu uz (datubze<b>.</b>tabula):';
$strMoveTableOK = 'Tabula %s tika prvietota uz %s.';
$strMoveTableSameNames = 'Nevar prvietot tabulu uz viu pau!';
$strMultilingual = 'daudzvalodu';
$strMustSelectFile = 'Ldzu izvlieties failu, kuru Js gribat ievietot.';
$strMySQLCharset = 'MySQL kodjums';
$strMySQLConnectionCollation = 'MySQL konekcijas krtoana';
$strMySQLReloaded = 'MySQL serveris tika prldts.';
$strMySQLSaid = 'MySQL teica: ';
$strMySQLServerProcess = 'MySQL %pma_s1% strd uz %pma_s2%, lietotjs %pma_s3%';
$strMySQLShowProcess = 'Pardt procesus';
$strMySQLShowStatus = 'Pardt MySQL izpildes laika informciju';
$strMySQLShowVars = 'Pardt MySQL sistmas maingos';

$strName = 'Nosaukums';
$strNeedPrimaryKey = 'Nodefinjiet primro atslgu ai tabulai.';
$strNext = 'Nkamie';
$strNo = 'N';
$strNoActivity = 'Nebija aktivittes vairk k %s sekunu laik, ldzu autorizjieties vlreiz';
$strNoDatabases = 'Nav datubzu';
$strNoDatabasesSelected = 'Datubze nav izvlta.';
$strNoDescription = 'Bez apraksta';
$strNoDropDatabases = '"DROP DATABASE" komanda ir aizliegta.';
$strNoExplain = 'Neizskaidrot SQL';
$strNoFrames = 'phpMyAdmin ir vairk draudzgs <b>freimu atbalstom</b> prlkprogrammm.';
$strNoIndex = 'Nav definti indeksi!';
$strNoIndexPartsDefined = 'Nav definto indeksa dau!';
$strNoModification = 'Netika labots';
$strNoOptions = 'im formtam nav opciju';
$strNoPassword = 'Nav paroles';
$strNoPermission = 'Web serverim nav tiesbu rakstt fail %s.';
$strNoPhp = 'Bez PHP koda';
$strNoPrivileges = 'Nav priviliju';
$strNoQuery = 'Nav SQL vaicjuma!';
$strNoRights = 'Jums nav pietiekoi tiesbu, lai atrastos eit tagad!';
$strNoRowsSelected = 'Rindas nav iezmtas';
$strNoSpace = 'Nepietiek vietas, lai saglabtu failu %s.';
$strNoTablesFound = 'Tabulas nav atrastas aj datubz.';
$strNoThemeSupport = 'Nav tmu atbalsta, ldzu prbaudiet jsu konfigurciju un/vai Jsu tmas direktorij %s.';
$strNoUsersFound = 'Lietotji netika atrasti.';
$strNoValidateSQL = 'Neprbaudt SQL';
$strNone = 'Nav';
$strNotNumber = 'Tas nav numurs!';
$strNotOK = 'nav OK';
$strNotSet = 'Tabula <b>%s</b> nav atrasta vai nav atzmeta iek %s';
$strNull = 'Nulle';
$strNumSearchResultsInTable = '%s rezultti tabul <i>%s</i>';
$strNumSearchResultsTotal = '<b>Kopum:</b> <i>%s</i> rezultti';
$strNumTables = 'Tabulas';

$strOK = 'Labi';
$strOftenQuotation = 'Parasti pdias. NEOBLIGTS nozm, ka tikai \'char\' un \'varchar\' tipa lauki tiek norobeoti ar o simbolu.';
$strOperations = 'Darbbas';
$strOperator = 'Operators';
$strOptimizeTable = 'Optimizt tabulu';
$strOptionalControls = 'Neobligts. Nosaka, k rakstt vai last specils rakstzmes.';
$strOptionally = 'NEOBLIGTS';
$strOr = 'Vai';
$strOverhead = 'Prtri';
$strOverwriteExisting = 'Prrakstt eksistjoos failus';

$strPHP40203 = 'Js lietojat PHP versiju 4.2.3, kurai ir nopietna kda daudzbaitu rindiu funkcijs (mbstring). Skatt PHP bug report 19404. S PHP versija nav rekomendjama lietoanai ar phpMyAdmin.';
$strPHPVersion = 'PHP Versija';
$strPageNumber = 'Lapas numurs:';
$strPaperSize = 'Papra izmrs';
$strPartialText = 'Daji teksti';
$strPassword = 'Parole';
$strPasswordChanged = 'Lietotja %s parole tika veiksmgi mainta.';
$strPasswordEmpty = 'Parole nav nordta!';
$strPasswordHashing = 'Paroles jaukana';
$strPasswordNotSame = 'Paroles nesakrt!';
$strPdfDbSchema = 'Datubzes "%s" shma, %s. lapa';
$strPdfInvalidTblName = 'Tabula "%s" neeksist!';
$strPdfNoTables = 'Nav tabulu';
$strPerHour = 'stund';
$strPerMinute = 'mint';
$strPerSecond = 'sekund';
$strPersian = 'Persieu';
$strPhoneBook = 'telefonu grmata';
$strPhp = 'Izveidot PHP kodu';
$strPmaDocumentation = 'phpMyAdmin dokumentcija';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktvai ir JBT nodefintai Jsu konfigurcijas fail!';
$strPolish = 'Pou';
$strPortrait = 'Portrets';
$strPos1 = 'Skums';
$strPrevious = 'Iepriekjie';
$strPrimary = 'Primr';
$strPrimaryKeyHasBeenDropped = 'Primr atslga tika izdzsta';
$strPrimaryKeyName = 'Primrs atslgas nosaukumam jbt... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>jbt</b> tikai un <b>viengi</b> primrs atslgas indeksa nosaukumam!)';
$strPrint = 'Drukt';
$strPrintView = 'Izdrukas versija';
$strPrintViewFull = 'Drukas skats (ar pilniem tekstiem)';
$strPrivDescAllPrivileges = 'Iekauj visas privilijas, izemot GRANT.';
$strPrivDescAlter = 'auj maint esoo tabulu struktru.';
$strPrivDescCreateDb = 'auj veidot jaunas datubzes un tabulas.';
$strPrivDescCreateTbl = 'auj veidot jaunas tabulas.';
$strPrivDescCreateTmpTable = 'auj veidot pagaidu tabulas.';
$strPrivDescDelete = 'auj dzst datus.';
$strPrivDescDropDb = 'auj dzst datubzes un tabulas.';
$strPrivDescDropTbl = 'auj dzst tabulas.';
$strPrivDescExecute = 'auj palaist saglabts procedras; vl nestrd aj MySQL versij.';
$strPrivDescFile = 'auj importt/eksportt datus no/uz failiem.';
$strPrivDescGrant = 'auj pievienot lietotjus un privilijas bez priviliju tabulu prldanas.';
$strPrivDescIndex = 'auj veidot un dzst indeksus.';
$strPrivDescInsert = 'auj ievietot un maint datus.';
$strPrivDescLockTables = 'auj blot tabulas tekoajai darbbai.';
$strPrivDescMaxConnections = 'Ierobeo jauno konekciju skaitu, ko lietotjs var atvrt stundas laik.';
$strPrivDescMaxQuestions = 'Ierobeo vaicjumu skaitu, ko lietotjs var mostt uz serveri stundas laik.';
$strPrivDescMaxUpdates = 'Ierobeo komandu skaitu, kas maina kas maina tabulas vai datubzes, ko lietotjs var izpildt stundas laik.';
$strPrivDescProcess3 = 'auj nogalint citu lietotju procesus.';
$strPrivDescProcess4 = 'auj apskatt pieprasjumu un procesu sarakstus.';
$strPrivDescReferences = 'Nedarbojas aj MySQL versij.';
$strPrivDescReload = 'auj prldt servera iestdjumus un iztukot servera keu.';
$strPrivDescReplClient = 'Dod lietotjam tiesbas jautt, kur ir replikcijas oriinli / kopijas.';
$strPrivDescReplSlave = 'Nepiecieams replikciju kopijm.';
$strPrivDescSelect = 'auj last datus.';
$strPrivDescShowDb = 'Dod pieeju pilnam datubzu sarakstam.';
$strPrivDescShutdown = 'auj apstdint serveri.';
$strPrivDescSuper = 'auj pieslgties pat tad, ja ir sasniegts maksimlais konekciju skaits; Nepiecieams vairumam administratvo operciju, k globlo maingo maia vai citu lietotju procesu nogalinana.';
$strPrivDescUpdate = 'auj maint datus.';
$strPrivDescUsage = 'Nav priviliju.';
$strPrivileges = 'Privilijas';
$strPrivilegesReloaded = 'Privilijas tika veiksmgi prldtas.';
$strProcesslist = 'Procesu saraksts';
$strPutColNames = 'Likt kolonnu nosaukumus pirmaj rind';

$strQBE = 'Vaicjums pc parauga';
$strQBEDel = 'Dzst';
$strQBEIns = 'Ielikt';
$strQueryFrame = 'Vaicjuma logs';
$strQueryOnDb = 'SQL vaicjums uz datubzes <b>%s</b>:';
$strQuerySQLHistory = 'SQL vsture';
$strQueryStatistics = '<b>Pieprasjumu statistika</b>: %s pieprasjumi tika nostti uz serveri kop t palaians bra.';
$strQueryTime = 'Vaicjums ilga %01.4f s';
$strQueryType = 'Vaicjuma tips';
$strQueryWindowLock = 'Neprrakstt o vaicjumu rpus  loga';

$strReType = 'Atkrtojiet';
$strReceived = 'Saemts';
$strRecords = 'Ieraksti';
$strReferentialIntegrity = 'Prbaudt referencilo integritti:';
$strRefresh = 'Atjaunot';
$strRelationNotWorking = 'Papildiespjas darbam ar saisttm tabulm tika izslgtas. Lai uzzintu kpc, klikkiniet %seit%s.';
$strRelationView = 'Relciju prskats';
$strRelationalSchema = 'Relciju shma';
$strRelations = 'Relcijas';
$strRelationsForTable = 'RELCIJAS TABULAI';
$strReloadFailed = 'Nesanca prldt MySQL serveri.';
$strReloadMySQL = 'Prldt MySQL serveri';
$strReloadingThePrivileges = 'Prldjam privilijas';
$strRemoveSelectedUsers = 'Dzst izvltos lietotjus';
$strRenameDatabaseOK = 'Datubze %s tika prsaukta par %s';
$strRenameTable = 'Prsaukt tabulu uz';
$strRenameTableOK = 'Tabula %s tika prsaukta par %s';
$strRepairTable = 'Restaurt tabulu';
$strReplace = 'Aizvietot';
$strReplaceNULLBy = 'Aizvietot NULL ar';
$strReplaceTable = 'Aizvietot tabulas datus ar datiem no faila';
$strReset = 'Atcelt';
$strResourceLimits = 'Resursu ierobeojumi';
$strRevoke = 'Atsaukt';
$strRevokeAndDelete = 'Atemt visas aktvs privilijas lietotjiem, un pc tam dzst tos.';
$strRevokeAndDeleteDescr = 'Lietotji saglab iespeju lietot datubzes, ldz privilijas tiek prldtas.';
$strRevokeMessage = 'Js atmt privilgijas lietotjam %s';
$strRomanian = 'Rumu';
$strRowLength = 'Rindas garums';
$strRowSize = ' Rindas izmrs ';
$strRows = 'Rindas';
$strRowsFrom = 'rindas skot no';
$strRowsModeFlippedHorizontal = 'horizontl (pagriezti virsraksti)';
$strRowsModeHorizontal = 'horizontl';
$strRowsModeOptions = '%s skat un atkrtot virsrakstus ik pc %s rindm';
$strRowsModeVertical = 'vertikl';
$strRowsStatistic = 'Rindas statistika';
$strRunQuery = 'Izpildt vaicjumu';
$strRunSQLQuery = 'Izpildt SQL vaicjumu(s) uz datubzes %s';
$strRunning = 'atrodas uz %s';
$strRussian = 'Krievu';

$strSQL = 'SQL';
$strSQLExportType = 'Eksporta veids';
$strSQLOptions = 'SQL opcijas';
$strSQLParserBugMessage = 'Iespjams, ka Js esat atradui kdu SQL interpretator. Ldzu apskatiet Jsu vaicjumu citgk, un prbaudiet, ka pdias ir pareizas un nav sajauktas. Cits kdas iemesls var bt tas, ka Js atstjt failu ar binro vrtbu rpus pdis iekaut teksta lauka. Js varat ar izmint savu vaicjumu MySQL komandrindas interfeis. MySQL servera kdas paziojums zemk, ja tds ir, var ar paldzt Jums diagnostict problmu. Ja problma paliek, vai ar iek phpMyAdmin kda ir, bet komandrind nav, ldzu samaziniet Jsu SQL vaicjumu ldz vienkram vaicjumam kas izsauc problmas, un atstiet mums ziojumu par kdu, iekaujot taj datus no IZGRIEZT sekcijas zemk:';
$strSQLParserUserError = 'Izkats, ka Jsu SQL vaicajum ir kda. MySQL servera kdas pazinojums zemk, ja tds ir, var ar paldzet Jums diagnostict problmu.';
$strSQLQuery = 'SQL vaicjums';
$strSQLResult = 'SQL rezultts';
$strSQPBugInvalidIdentifer = 'Nedergs identifikators';
$strSQPBugUnclosedQuote = 'Neaizvrtas pdias';
$strSQPBugUnknownPunctuation = 'Nezinm punktucijas zme';
$strSave = 'Saglabt';
$strSaveOnServer = 'Saglabt uz servera direktorij %s';
$strScaleFactorSmall = 'Mrogoanas faktors ir prk mazs, lai shma ietilptu vien lap';
$strSearch = 'Meklt';
$strSearchFormTitle = 'Meklt datubz';
$strSearchInTables = 'Tabul(s):';
$strSearchNeedle = 'Vrdi vai vrtbas meklanai (aizstjjzme: "%"):';
$strSearchOption1 = 'kaut viens no vrdiem';
$strSearchOption2 = 'visi vrdi';
$strSearchOption3 = 'precza frze';
$strSearchOption4 = 'k regulr izteiksme';
$strSearchResultsFor = 'Meklanas rezultti "<i>%s</i>" %s:';
$strSearchType = 'Atrast:';
$strSecretRequired = 'Konfigurcijas fails tagad prasa slepeno paroli (blowfish_secret).';
$strSelectADb = 'Ldzu izvlieties datubzi';
$strSelectAll = 'Iezmt visu';
$strSelectBinaryLog = 'Izvlieties binro log-failu apskatei';
$strSelectFields = 'Izvlieties laukus (kaut vienu):';
$strSelectNumRows = 'vaicjum';
$strSelectTables = 'Izvlieties tabulas';
$strSend = 'Saglabt k failu';
$strSent = 'Nostts';
$strServer = 'Serveris';
$strServerChoice = 'Servera izvle';
$strServerNotResponding = 'Serveris neatbild';
$strServerStatus = 'Izpildes laika informcija';
$strServerStatusUptime = 'is MySQL serveris strd %s. Tas tika palaists %s.';
$strServerTabProcesslist = 'Procesi';
$strServerTabVariables = 'Maingie';
$strServerTrafficNotes = '<b>Servera trafiks</b>: s tabulas parda  MySQL servera tkla trafika statistiku kop t palaianas.';
$strServerVars = 'Servera maingie un konfigurcija';
$strServerVersion = 'Servera versija';
$strSessionValue = 'Sesijas vrtba';
$strSetEnumVal = 'Ja lauka tips ir "enum" vai "set", ldzu ievadiet vrtbas atbilstoi im formatam: \'a\',\'b\',\'c\'...<br />Ja Jums vajag ielikt atpakajo slpsvtru (\) vai vienkro pdiu (\') kd no m vrtbm, lieciet ts priek atpakajo slpsvtru (piemram, \'\\\\xyz\' vai \'a\\\'b\').';
$strShow = 'Rdt';
$strShowAll = 'Rdt visu';
$strShowColor = 'Rdt krsas';
$strShowDatadictAs = 'Datu vrdncas formats';
$strShowFullQueries = 'Rdt pilnos vaicjumus';
$strShowGrid = 'Rdt rei';
$strShowPHPInfo = 'Pardt PHP informciju';
$strShowTableDimension = 'Rdit tabulu izmrus';
$strShowTables = 'Rdt tabulas';
$strShowThisQuery = ' Rdt o vaicjumu eit atkal ';
$strShowingRecords = 'Pardu rindas';
$strSimplifiedChinese = 'Vienkrota nieu';
$strSingly = '(atsevii)';
$strSize = 'Izmrs';
$strSlovak = 'Slovku';
$strSlovenian = 'Slovu';
$strSort = 'Krtoana';
$strSortByKey = 'Krtot pc atslgas';
$strSpaceUsage = 'Diska vietas lietoana';
$strSpanish = 'Spu';
$strSplitWordsWithSpace = 'Vrdi ir atdalti ar tukumu (" ").';
$strStatCheckTime = 'Pdj prbaude';
$strStatCreateTime = 'Izveidoana';
$strStatUpdateTime = 'Pdj atjaunoana';
$strStatement = 'Parametrs';
$strStatus = 'Statuss';
$strStrucCSV = 'CSV dati';
$strStrucData = 'Struktra un dati';
$strStrucDrop = 'Pievienot tabulu dzanas komandas';
$strStrucExcelCSV = 'CSV dati MS Excel formt';
$strStrucNativeExcel = 'Dati MS Excel format';
$strStrucOnly = 'Tikai struktra';
$strStructPropose = 'Ieteikt tabulas sruktru';
$strStructure = 'Struktra';
$strSubmit = 'Nostt';
$strSuccess = 'Jsu SQL vaicjums tika veiksmgi izpildts';
$strSum = 'Kopum';
$strSwedish = 'Zviedru';
$strSwitchToDatabase = 'Prslgties uz nokopto datubzi';
$strSwitchToTable = 'Prslgties uz nokopto tabulu';

$strTable = 'Tabula';
$strTableComments = 'Komentrs tabulai';
$strTableEmpty = 'Tabulas nosaukums nav nordts!';
$strTableHasBeenDropped = 'Tabula %s tika izdzsta';
$strTableHasBeenEmptied = 'Tabula %s tika iztukota';
$strTableHasBeenFlushed = 'Tabula %s tika atsvaidzinta';
$strTableMaintenance = 'Tabulas apkalpoana';
$strTableOfContents = 'Satura rdtjs';
$strTableOptions = 'Tabulas opcijas';
$strTableStructure = 'Tabulas struktra tabulai';
$strTableType = 'Tabulas tips';
$strTables = '%s tabula(s)';
$strTakeIt = 'izmantot o stilu';
$strTblPrivileges = 'Tabulu specifisks privilijas';
$strTextAreaLength = ' Sava garuma d,<br /> is lauks var bt neredijams ';
$strThai = 'Taizemieu';
$strTheContent = 'Jsu faila saturs tika ievietots.';
$strTheContents = 'Faila saturs aizvieto izvlts tabulas saturu rindim ar identisko primrs vai unikls atslgas vrtbu.';
$strTheTerminator = 'Lauku atdaltjs.';
$strTheme = 'Tma / Stils';
$strThisHost = 'is hosts';
$strThisNotDirectory = 'T nebija direktorija';
$strThreadSuccessfullyKilled = 'Process %s tika veiksmgi nogalints.';
$strTime = 'Laiks';
$strToggleScratchboard = 'pardt/noslpt piezmju tafeli';
$strTotal = 'kop';
$strTotalUC = 'Kop';
$strTraditionalChinese = 'Tradicionla nieu';
$strTraditionalSpanish = 'Tradicionl spu';
$strTraffic = 'Datu apmaia';
$strTransformation_application_octetstream__download = 'Rdt saiti uz lauka binro datu lejupldi. Pirm opcija ir binr faila nosaukums. Otr opcija ir iespjamais lauka nosaukums tabulas rind, kas satur faula nosaukumu. Ja izmantojat otro opciju, pirmo atstjiet tuko.';
$strTransformation_image_jpeg__inline = 'Parda klikinmo sktlu; opcijas: platums, augstums pikseos (saglabjot oriinls proporcijas)';
$strTransformation_image_jpeg__link = 'Parda linku uz o attlu (tiea blob lauka lajuplde).';
$strTransformation_image_png__inline = 'Skatties image/jpeg: k ierindotu attlu';
$strTransformation_text_plain__dateformat = 'em TIME, TIMESTAMP vai DATETIME lauku, un format to izmantojot Jsu loklo datuma formatu. Pirm opcija ir nobde (stunds), kas tiks pievienota timestamp laukam (noklust: 0). Otr opcija ir datuma formats, saska ar PHP finkcijas strftime() parametriem.';
$strTransformation_text_plain__external = 'Tikai LINUX: Palai rjo aplikciju un padod lauka datus ts standartievad. Atgrie aplikcijas standartizvadi. Noklusjums ir Tidy, kas izskaistina HTML kodu. Drobas apsvrumu d, nepiecieams manuli redit failu libraries/transformations/text_plain__external.inc.php un ielikt rkus, kurus Js ataujat palaist. Pirm opcija ir programmas numurs, ko Js vlaties lietot, otr opcija ir parametri ai programmai. Tre opcija, ja ir vienda ar 1, konvert izvadi, izmantojot htmlspecialchars() (noklusjums ir 1). Ceturtais parametrs, ja viends ar 1, liek NOWRAP parametru satura nai, t k izvade tiks attlota bez prformatanas. (noklusjums ir 1)';
$strTransformation_text_plain__formatted = 'Saglab lauka oriinlo formatjumu. Specilo rakstzmju pasargana netiek veikta.';
$strTransformation_text_plain__imagelink = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir platums pikseos, tre ir augstums.';
$strTransformation_text_plain__link = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir linka nosaukums.';
$strTransformation_text_plain__substr = 'Parda tikai virknes dau. Pirm opcija ir nobde, kas nosaka, kur Jsu teksts skas (noklusjums 0). Otr opcija ir atgrieam teksta garums. Ja tuka, atgrie visu atlikuo tekstu. Tre opcija nosaka rakstzmes, kas tiks pievienotas apgriezts virknes gal (noklusjums: ...) .';
$strTruncateQueries = 'Ierobeot pardto vaicjumu garumu';
$strTurkish = 'Turku';
$strType = 'Tips';

$strUkrainian = 'Ukraiu';
$strUncheckAll = 'Neiezmt neko';
$strUnicode = 'Unikods';
$strUnique = 'Uniklais';
$strUnknown = 'nazinma';
$strUnselectAll = 'Neiezmt neko';
$strUpdComTab = 'Ldzu skatieties dokumentciju par to, k atjaunot \'Column_comments\' tabulu';
$strUpdatePrivMessage = 'Js modificjt privilijas objektam %s.';
$strUpdateProfileMessage = 'Profils tika modificts.';
$strUpdateQuery = 'Atjaunot vaicjumu';
$strUpgrade = 'Jums ir juzliek %s %s vai jaunks.';
$strUsage = 'Aizem';
$strUseBackquotes = 'Lietot apostrofa simbolu [`] tabulu un lauku nosaukumiem';
$strUseHostTable = 'Lietot hostu tabulu';
$strUseTabKey = 'Lietojiet TAB taustiu, lai prvietotos no vrtbas ldz vrtbai, vai CTRL+bultias, lai prvietotos jebkur viet';
$strUseTables = 'Lietot tabulas';
$strUseTextField = 'Lietot teksta lauku';
$strUseThisValue = 'Lietot o vrtbu';
$strUser = 'Lietotjs';
$strUserAlreadyExists = 'Lietotjs %s jau eksist!';
$strUserEmpty = 'Lietotja vrds nav nordts!';
$strUserName = 'Lietotjvrds';
$strUserNotFound = 'Izvltais lietotjs nav atrasts priviliju tabul.';
$strUserOverview = 'Lietotju prskats';
$strUsersDeleted = 'Izvltie lietotji tika veiksmgi dzsti.';
$strUsersHavingAccessToDb = 'Lietotji, kam ir pieja datubzei &quot;%s&quot;';

$strValidateSQL = 'Prbaudt SQL';
$strValidatorError = 'Nevar inicializt SQL prbaudtju. Ldzu prbaudiet, vai esat uzinstaljui nepiecieamos PHP paplainjumus, k aprakstts %sdokumentcij%s.';
$strValue = 'Vrtba';
$strVar = 'Maingais';
$strViewDump = 'Apskatt tabulas dampu (shmu)';
$strViewDumpDB = 'Apskatt datubzes dampu (shmu)';
$strViewDumpDatabases = 'Apskatt datubzu dampu (shmu)';

$strWebServerUploadDirectory = 'web servera augupieldes direktorija';
$strWebServerUploadDirectoryError = 'Direktoija, kuru nordijt augupieldei, nav pieejama';
$strWelcome = 'Laipni lgti %s';
$strWestEuropean = 'Rietumeiropas';
$strWildcard = 'aizstjjzme';
$strWindowNotFound = 'Neizdevs atjaunot galveno prlkprogramas logu. Varbt esat viu aizvrui, vai ar Jsu prlkprogramma bloe starplogu saskarsmi Jsu drobas iestdjumu d.';
$strWithChecked = 'Ar iezmto:';
$strWritingCommentNotPossible = 'Komentra rakstana nav iespjama';
$strWritingRelationNotPossible = 'Relcijas rakstana nav iespjama';
$strWrongUser = 'Kdains lietotjvrds/parole. Pieeja aizliegta.';

$strXML = 'XML';

$strYes = 'J';

$strZeroRemovesTheLimit = 'Piezme: o opciju uzstdana uz 0 (nulli) atce ierobeojumus.';
$strZip = 'Arhivts ar zip';

// To translate:
$strAfterInsertNext = 'Edit next row';  //to translate

$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate

$strSQLExportCompatibility = 'SQL export compatibility';  //to translate

$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
